from setuptools import setup

setup(name='ut95_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['ut95_distributions'],
      author='Usama Official',
      author_email='usamaofficial95@gmail.com',
      zip_safe=False)
